@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.15';
+$BankAccount::Validator::UK::VERSION   = '0.16';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
@@ -37,7 +37,7 @@ The module uses the algorithm provided by VOCALINK to validate the bank sort cod
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|http://www.vocalink.com/products/payments/customer-support-services/modulus-checking.aspx>
 
-It currently supports the document v3.20 dated 23rd Mar'2015.
+It currently supports the L<document|http://www.vocalink.com/media/700427/vocalink_-_validating_account_numbers_v3.20.pdf> v3.20 dated 23rd Mar'2015.
 
 Institutions covered by this document are below:
 
